# P2obt
<!-- Project Shields -->
[![License: MIT](https://img.shields.io/badge/license-MIT-green.svg)](https://opensource.org/licenses/MIT)
![Lifecycle: production](https://img.shields.io/badge/lifecycle-production-orange.svg)

The Phase 2 OB tools (p2obt) have been made to streamline/automate
the process of MATISSE observation (ob) preparation on p2.

* **Documentation**: [https://matisse-consortium.github.io/p2obt/](https://matisse-consortium.github.io/p2obt/)
* **Installation**: [https://matisse-consortium.github.io/p2obt/installation.html](https://matisse-consortium.github.io/p2obt/installation.html)
* **Getting Started**: [https://matisse-consortium.github.io/p2obt/getting_started.html](https://matisse-consortium.github.io/p2obt/getting_started.html) and the scripts in the `example/` directory.
* **Bug Reports**: [https://github.com/matisse-consortium/p2obt/issues](https://github.com/matisse-consortium/p2obt/issues)
* **Credit**: [https://matisse-consortium.github.io/p2obt/credit.html](https://matisse-consortium.github.io/p2obt/credit.html)
